<?php
/**
 * @version   $Id: kunenasocial.php,v ce52b4cd4b12 2011/02/10 16:38:00 likemandrake $
 * @author    Piotr Minkina <likemandrake@o2.pl>
 * @copyright Copyright (C) 2011 Piotr Minkina. All rights reserved.
 * @license   GNU/GPL version 2 or later; see LICENSE.txt
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

/**
 * JomSocial field type for Kunena Social
 *
 * @author Piotr Minkina <likemandrake@o2.pl>
 */
class CFieldsKunenaSocial
{
    /**
     * List of Kunena Social bookmarks, grouped by bookmark name
     *
     * @var array
     */
    protected static $_config;
    
    /**
     * You know... This is CONSTRUCTOR!
     *
     * Additionally loads ini file with Kunena Social bookmarks
     */
    public function __construct()
    {
        if (null === self::$_config)
        {
            self::$_config = parse_ini_file(dirname(__FILE__) . '/kunenasocial/bookmarks.ini', true);
        }
    }
    
    /**
     * Prepares and displays Kunena Social bookmark in user profile
     *
     * @param array $field
     * @return string
     */
    public function getFieldData(array $field)
    {
        $params       = new JParameter($field['params']);
        $kunenasocial = $params->get('kunenasocial');
        $value        = $field['value'];
        $attribs      = array();
        
        if (empty($value) || !isset(self::$_config[$kunenasocial]))
        {
            return $value;
        }
        $data = (array) self::$_config[$kunenasocial];
        
        CFactory::load('helpers', 'string');
        $attribs['title'] = CStringHelper::escape(sprintf($data['title'], $value));
        
        if (!isset($data['isurl']) || !$data['isurl'])
        {
            return '<span ' . JArrayHelper::toString($attribs) . '>'
                 . CStringHelper::escape(str_replace('##VALUE##', $value, $data['value']))
                 . '</span>';
        }
        $attribs['href']   = CStringHelper::escape(str_replace('##VALUE##', $value, $data['value']));
        $attribs['rel']    = 'nofollow';
        $attribs['target'] = '_blank';
        
        return '<a ' . JArrayHelper::toString($attribs) . '>'
             . CStringHelper::escape($value)
             . '</a>';
    }
    
    /**
     * Prepares and displays form field, editable in user profile
     *
     * @param stdClass $field
     * @param bool     $required
     * @return string
     */
    public function getFieldHTML(stdClass $field, $required)
    {
        $params    = new JParameter($field->params);
        $maxlength = $params->get('maxlength', 30);
        
        $class     = array('inputbox');
        
        CFactory::load('helpers', 'string');
        if (1 == $field->required)
        {
            $class[] = 'required';
        }
        if (!empty($field->tips))
        {
            $class[] = 'jomTips';
            $class[] = 'tipRight';
        }
        $inputAttribs = array
        (
            'type'      => 'text',
            'id'        => 'field' . $field->id,
            'name'      => 'field' . $field->id,
            'value'     => $field->value,
            'title'     => JText::_($field->name) . '::'. CStringHelper::escape(JText::_($field->tips)),
            'maxlength' => $maxlength,
            'size'      => 40,
            'class'     => join(' ', $class)
        );
        $spanAttribs = array
        (
            'id'    => 'errfield' . $field->id . 'msg',
            'style' => 'display: none;'
        );
        
        return '<input ' . JArrayHelper::toString($inputAttribs) . ' />'
             . '<span '  . JArrayHelper::toString($spanAttribs)  . '>&nbsp;</span>';
    }
    
    /**
     * Checks if value is valid
     *
     * @param string $value
     * @param bool   $required
     * @return bool
     */
    public function isValid($value, $required)
    {
        if ($required && empty($value))
        {
            return false;
        }
        return true;
    }
}
